/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Financas
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.financas;

import gestao.rodoviario.passagem.Passagem;
import gestao.rodoviario.passagem.CadastroDePassagem;
import gestao.rodoviario.viagem.Viagem;
import gestao.rodoviario.viagem.CadastroDeViagem;

import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * Financas  a classe que calcula as despesas, a arrecadao e o lucro da empresa
 *
 * Exemplo de uso:
 * Finacas financas = new Financa();
 *
 * @author  ADFT
 */
public class Financas {

    private int arrecadacao;
    private int despesas;
    private int lucro;
    private CadastroDePassagem passagensVendidas;
    private CadastroDeViagem viagensRealizadas;

    private CadastroDeViagem viagensMarcadas = new CadastroDeViagem();

   /**
    * Construtor da classe Financas
    */
    public Financas(int arrecadacao,
                    int despesas,
                    int lucro,
                    CadastroDePassagem passagensVendidas,
                    CadastroDeViagem viagensRealizadas) {
        this.arrecadacao = arrecadacao;
        this.despesas = despesas;
        this.lucro = lucro;
        this.passagensVendidas = passagensVendidas;
        this.viagensRealizadas = viagensRealizadas;
    }

   /**
    * Construtor da classe Financas
    */
    public Financas() {
        this.arrecadacao = 0;
        this.despesas = 0;
        this.lucro = 0;
        this.passagensVendidas = new CadastroDePassagem();
        this.viagensRealizadas = new CadastroDeViagem();
    }

   /**
    * Retorna a arrecadao da empresa
    *
    * @return  Arrecadacao em formato Inteiro
    */
    public int getArrecadacao()
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        this.setArrecadacao();
        return this.arrecadacao;
    }

   /**
    * Calcula e seta a arrecadaao da empresa
    */
    private void setArrecadacao() {
        int index = 0;
        int arrecadacaoTotal = 0;
        CadastroDePassagem percorrePassagens = this.passagensVendidas;
        Passagem array[] = percorrePassagens.getListaDePassagensCadastradas();
        while (array[index] != null) {
            arrecadacaoTotal = arrecadacaoTotal + array[index].getPreco();
            index = index + 1;
        }
        this.arrecadacao = arrecadacaoTotal;
    }

   /**
    * Retorna as despesas da empresa
    *
    * @return   Despesas em formato Inteiro
    */
    public int getDespesas()
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        this.setDespesas();
        return this.despesas;
    }

   /**
    * Calcula e seta as despesas da empresa
    */
    private void setDespesas()
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        int indexPassagem = 0;
        int indexViagem = 0;
        int despesa = 0;
        CadastroDePassagem percorrePassagens = this.passagensVendidas;
        Passagem array[] = percorrePassagens.getListaDePassagensCadastradas();

        while (array[indexPassagem] != null) {
            indexViagem = 0;
            Viagem viagens[] = this.viagensRealizadas
                               .consultarViagemDaListaDeViagem(array[indexPassagem]
                               .getViagem());

            while (viagens[indexViagem] != null) {
                if(!viagemJaMarcada(viagens[indexViagem]))
                    despesa = despesa + viagens[indexViagem].getCustoDaViagem();
                indexViagem++;
            }
            indexPassagem++;
        }
        this.despesas = despesa;
    }

   /**
    * Diz se a viagem dada ja foi marcada
    *
    * @return   true se a viagem ja foi marcada
    *           false caso contrario
    */
    private boolean viagemJaMarcada(Viagem viagem) {
        boolean resposta = false;
        try {
            viagensMarcadas.inserirViagemNaListaDeViagem(viagem);
            resposta = false;
        } catch (ObjetoJaCadastradoException ojcexp) {
            resposta = true;
        } catch (ObjetoVazioException ovexp) {
        }
        return resposta;
    }

   /**
    * Retorna o lucro da empresa
    *
    * @return     Lucro em formato Inteiro
    */
    public int getLucro()
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        this.setLucro();
        return this.lucro;
    }

   /**
    * Seta a arrecadao, seta a despesa e calcula o lucro
    */
    private void setLucro()
       throws ObjetoJaCadastradoException, ObjetoVazioException {
        //this.setArrecadacao();
        //this.setDespesas();
        this.lucro = (this.arrecadacao - this.despesas);
    }

}
