/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: CadastroDeFuncionario
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.funcionario;

import gestao.rodoviario.excecoes.ObjetoInexistenteException;
import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * CadastroDeFuncionario  um tipo que possui os mtodos de gerenciamento
 * dos funcionrios do sistema
 *
 * Exemplo de uso:
 * CadastroDeFuncionario cadastroFuncinarios = new CadastroDeFuncionario()
 *
 * @author  ADFT
 */
public class CadastroDeFuncionario {

    private RepositorioDeFuncionario listaDeFuncionario;

   /**
    * Construtor da classe CadastroDeOnibus
    */
    public CadastroDeFuncionario() {
        listaDeFuncionario = new RepositorioDeFuncionario();
    }

   /**
    * Encapsulamento do metodo RepositorioDeFuncionario.inserirFuncionario()
    */
    public void inserirFuncionarioNaListaDeFuncionario(Funcionario funcionarioParaInserir)
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        listaDeFuncionario.inserirFuncionario(funcionarioParaInserir);
    }

   /**
    * Encapsulamento do metodo RepositorioDeFuncionario.removerFuncionario()
    */
    public void removerFuncionarioDaListaDeFuncionario(Funcionario funcionarioParaRemover)
        throws ObjetoInexistenteException, ObjetoVazioException {
        listaDeFuncionario.removerFuncionario(funcionarioParaRemover);
    }

   /**
    * Encapsulamento do mtodo
    * RepositorioDeFuncionario.procurarFuncionario().getIterador()
    *
    * @return   Array com o resultado da pesquisa
    */
    public Funcionario[] consultarFuncionarioDaListaDeFuncionario(Funcionario funcionarioParaConsultar)
        throws ObjetoVazioException,ObjetoJaCadastradoException,ObjetoInexistenteException {
        Funcionario[] resultado = listaDeFuncionario
                                  .procurarFuncionario(funcionarioParaConsultar)
                                  .getIterador();
        return resultado;
    }

   /**
    * Retorna todos os funcionrios cadastrados
    *
    * @return   Array com todos funcionrios cadastrados
    */
    public Funcionario[] getListaDeFuncionariosCadastrados() {
        return (listaDeFuncionario.getIterador());
    }
}
