/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Funcionario
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.funcionario;

import gestao.rodoviario.pessoa.Pessoa;


/**
 * Funcionario  um tipo que representa o comportamento de um funcionrio
 * no sistema
 *
 * Exemplo de uso:
 * Funcionario funcionario = new Funcionario()
 *
 * @author  ADFT
 */
public class Funcionario extends Pessoa {

    private String cargoDoFuncionario;

   /**
    * Construtor da classe Funcionario.
    *
    * @param nomeDoFuncionario        Nome do funcionrio
    * @param identidadeDoFuncionario  Identidade do funcionrio
    * @param cargoDoFuncionario       Cargo do funcionrio
    */
    public Funcionario(String nomeFuncionario,
                       String identidadeFuncionario,
                       String cargoFuncionario) {
       super(nomeFuncionario, identidadeFuncionario);
       this.cargoDoFuncionario = cargoFuncionario;
    }

    public Funcionario() {
       super("","");
       this.cargoDoFuncionario = "";
    }

   /**
    * Seta o cargo do funcionrio
    *
    * @param   Uma String contendo o cargo do funcionrio
    */
    public void setCargoDoFuncionario(String cargo) {
        this.cargoDoFuncionario = cargo;
    }

   /**
    * Retorna o cargo do funcionrio
    *
    * @return   Uma String contendo o cargo do funcionrio
    */
    public String getCargoDoFuncionario() {
        return this.cargoDoFuncionario;
    }

   /**
    * Verifica se dois funcionrios so iguais comparando seus atributos
    *
    * @return   true se existe igualdade entre todos os atributos
    *           false caso contrrio
    */
    public boolean equals(Funcionario funcionario) {
        boolean resposta = false;
        if ((this.getNome().equals(funcionario.getNome()))) {
            if (this.getIdentidade()
                .equals(funcionario.getIdentidade())) {
                if (this.cargoDoFuncionario
                    .equals(funcionario.getCargoDoFuncionario())) {
                    resposta = true;
                }
            }
        }
        return resposta;
    }

   /**
    * Verifica se o funcionrios tem seus atributos nulos
    *
    * @return   true se todos os atributos so nulos
    *           false caso contrrio
    */
    public boolean isNull() {
        boolean resposta = false;

        if (this.getNome().equals("")) {
            if (this.getIdentidade().equals("")) {
                if (this.cargoDoFuncionario.equals("")) {
                    resposta = true;
                }
            }
        }
        return resposta;
    }

   /**
    * Verifica se dois funcionrios so semelhantes
    *
    * @return   true se todos os atributos no nulos so iguais
    *           false caso contrrio
    */
    public boolean match(Funcionario funcionario) {
        boolean resposta = true;

        if (funcionario.isNull()) {
            resposta = false;
        }

        if (!funcionario.getNome().equals("")) {
            if(!(this.getNome().equals(funcionario.getNome()))) {
                resposta = false;
            }
        }

        if (resposta) {
            if(!funcionario.getIdentidade().equals("")) {
                if(!this.getIdentidade()
                   .equals(funcionario.getIdentidade())) {
                    resposta = false;
                }
            }
        }

        if (resposta) {
            if(!funcionario.getCargoDoFuncionario().equals("")) {
                if(!this.cargoDoFuncionario
                   .equals(funcionario.getCargoDoFuncionario())) {
                    resposta = false;
                }
            }
        }
        return resposta;
    }
}
