/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: CadastroDeOnibus
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.onibus;

import gestao.rodoviario.excecoes.ObjetoInexistenteException;
import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * CadastroDeOnibus  um tipo que possui os mtodos de gerenciamento da frota
 * do sistema
 *
 * Exemplo de uso:
 * CadastroDeOnibus cadastroFrota = new CadastroDeOnibus()
 *
 * @author  ADFT
 */
public class CadastroDeOnibus {

    private InterfaceDoRepositorioDeOnibus frota;

   /**
    * Construtor da classe CadastroDeOnibus
    */
    public CadastroDeOnibus() {
        frota = new RepositorioDeOnibus();
    }

   /**
    * Encapsulamento do metodo RepositorioDeOnibus.inserirOnibus()
    */
    public void inserirOnibusNaFrota(Onibus onibusParaInserir)
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        frota.inserirOnibus(onibusParaInserir);
    }

   /**
    * Encapsulamento do metodo RepositorioDeOnibus.removerOnibus()
    */
    public void removerOnibusDaFrota(Onibus onibusParaRemover)
        throws ObjetoInexistenteException, ObjetoVazioException {
        frota.removerOnibus(onibusParaRemover);
    }

   /**
    * Encapsulamento do mtodo
    * RepositorioDeOnibus.procurarOnibus().getIterador()
    *
    * @return   Array com o resultado da pesquisa
    */
    public Onibus[] consultarOnibusDaFrota(Onibus onibusParaConsultar)
        throws ObjetoVazioException, ObjetoJaCadastradoException, ObjetoInexistenteException {

        Onibus[] resultado = frota.procurarOnibus(onibusParaConsultar).getIterador();

        return resultado;
    }

   /**
    * Retorna todos os nibus cadastrados na frota
    *
    * @return   Array com todos os onibus da frota
    */
    public Onibus[] getTodosOnibusDaFrota() {
        return (frota.getIterador());
    }
}

