/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Onibus
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.onibus;


/**
 * Onibus  um tipo que representa o comportametno de um nibus no sistema
 *
 * Exemplo de uso:
 * Onibus onibus = new Onibus()
 *
 * @author  ADFT
 */
public class Onibus {

    private String modelo;
    private String dataDeRevisao;
    private String numero;
    private String anoDeFabricacao;

   /**
    * Construtor da classe Onibus
    *
    * @param modelo               Modelo do nibus
    * @param dataRevisao          Data de reviso
    * @param numero               Nmero do nibus
    * @param anoFabricacao        Ano de fabricao
    */
    public Onibus(String modelo, String dataRevisao,String numero, String anoFabricacao) {
       this.modelo = modelo;
       this.dataDeRevisao = dataRevisao;
       this.numero = numero;
       this.anoDeFabricacao = anoFabricacao;
    }

   /**
    * Construtor da classe Onibus que cria um objeto nibus nulo
    */
    public Onibus() {
        this.modelo = "";
        this.dataDeRevisao = "";
        this.numero = "";
        this.anoDeFabricacao = "";
    }

   /**
    * Retorna o modelo do nibus
    *
    * @return   Uma String contendo o modelo do nibus
    */
    public String getModeloOnibus() {
        return this.modelo;
    }

   /**
    * Seta o modelo do nibus
    *
    * @param   Uma String contendo o modelo do nibus
    */
    public void setModeloOnibus(String modelo) {
        this.modelo = modelo;
    }

   /**
    * Retorna a data de reviso do nibus
    *
    * @return   Uma String contendo a data de reviso do nibus
    */
    public String getDataRevOnibus() {
        return this.dataDeRevisao;
    }

   /**
    * Seta a data de reviso do nibus
    *
    * @param   Uma String contendoa data de reviso do nibus
    */
    public void setDataOnibus(String dataRev) {
        this.dataDeRevisao = dataRev;
    }

   /**
    * Retorna nmero do nibus
    *
    * @return   Um inteiro contendo o nmero do nibus
    */
    public String getNumeroOnibus() {
        return this.numero;
    }

   /**
    * Seta o nmero do nibus
    *
    * @param   Um inteiro contendo o nmero do nibus
    */
    public void setNumeroOnibus(String numero) {
        this.numero = numero;
    }

   /**
    * Retorna o ano de fabricao do nibus
    *
    * @return   Um inteiro contendo o ano de fabricao do nibus
    */
    public String getAnoFabOnibus() {
        return this.anoDeFabricacao;
    }

   /**
    * Seta o ano de fabricao do nibus
    *
    * @param   Um inteiro contendo o ano de fabricao do nibus
    */
    public void setAnoFabOnibus(String ano) {
        this.anoDeFabricacao = ano;
    }

   /**
    * Verifica se dois nibus so iguais comparando seus atributos
    *
    * @return   true se existe igualdade entre todos os atributos
    *           false caso contrrio
    */
    public boolean equals(Onibus onibus) {
        boolean resposta = false;
        if ((this.modelo.equals(onibus.modelo))) {
            if (this.dataDeRevisao.equals(onibus.dataDeRevisao)) {
                if (this.numero.equals(onibus.numero)) {
                    if (this.anoDeFabricacao.equals(onibus.anoDeFabricacao)) {
                        resposta = true;
                    }
                }
            }
        }
        return resposta;
    }

   /**
    * Verifica se o nibus tem seus atributos nulos
    *
    * @return   true se todos os atributos so nulos
    *           false caso contrrio
    */
    public boolean isNull() {
        boolean resposta = false;
        if (this.modelo.equals("")) {
            if (this.dataDeRevisao.equals("")) {
                if (this.numero.equals("")) {
                    if (this.anoDeFabricacao.equals("")) {
                        resposta = true;
                    }
                }
            }
        }
        return resposta;
    }

    /**
    * Verifica se dois nibus so semelhantes
    *
    * @return   true se todos os atributos no nulos so iguais
    *           false caso contrrio
    */
    public boolean match(Onibus onibus) {
        boolean resposta = true;

        if (onibus.isNull()) {
            resposta = false;
        }

        if (!onibus.getModeloOnibus().equals("")) { // se modelo no  nulo:
            if (!this.modelo.equals(onibus.getModeloOnibus())) {
                resposta = false;

            }
        }

        if (resposta) {
            if (!onibus.getDataRevOnibus().equals("")) {
                if (!this.dataDeRevisao.equals(onibus.getDataRevOnibus())) {
                    resposta = false;

                }
            }
        }

        if (resposta) {
            if (!onibus.getNumeroOnibus().equals("")) {
                if (!this.numero.equals(onibus.getNumeroOnibus())) {
                    resposta = false;

                }
            }
        }


        if (resposta) {
            if (!onibus.getAnoFabOnibus().equals("")) {
                if (!this.anoDeFabricacao.equals(onibus.getAnoFabOnibus())) {
                    resposta = false;

                }
            }
        }

        return resposta;
    }
}
