/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: CadastroDePassageiro
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passageiro;

import gestao.rodoviario.excecoes.ObjetoInexistenteException;
import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * CadastroDePassageiro  um tipo que possui os mtodos de gerenciamento
 * dos passageiros do sistema
 *
 * Exemplo de uso:
 * CadastroDePassageiro cadastroPassageiros = new CadastroDePassageiro()
 *
 * @author  ADFT
 */
public class CadastroDePassageiro {

    private RepositorioDePassageiro listaDePassageiro;

   /**
    * Construtor da classe CadastroDePassageiro
    */
    public CadastroDePassageiro() {
        listaDePassageiro = new RepositorioDePassageiro();
    }

   /**
    * Encapsulamento do metodo RepositorioDePassageiro.inserirPassageiro()
    */
    public void inserirPassageiroNaListaDePasageiro(Passageiro passageiroParaInserir)
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        listaDePassageiro.inserirPassageiro(passageiroParaInserir);
    }

   /**
    * Encapsulamento do metodo RepositorioDePassageiro.removerPassageiro()
    */
    public void removerPassageiroDaListaDePasageiro(Passageiro passageiroParaRemover)
        throws ObjetoInexistenteException, ObjetoVazioException {
        listaDePassageiro.removerPassageiro(passageiroParaRemover);
    }

   /**
    * Encapsulamento do mtodo
    * RepositorioDePassageiro.procurarPassageiro().getIterador()
    *
    * @return   Array com o resultado da pesquisa
    */
    public Passageiro[] consultarPassageiroDaListaDePasageiro(Passageiro passageiroParaConsultar)
        throws ObjetoVazioException, ObjetoJaCadastradoException, ObjetoInexistenteException {
        Passageiro[] resultado = listaDePassageiro
                                 .procurarPassageiro(passageiroParaConsultar)
                                 .getIterador();
        return resultado;
    }

   /**
    * Retorna todos os passageiros cadastrados
    *
    * @return   Array com todos passageiros cadastrados
    */
    public Passageiro[] getListaDePassagirosCadastrados() {
        return (this.listaDePassageiro.getIterador());
    }
}
