/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Passagem
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passageiro;

import gestao.rodoviario.passagem.Passagem;
import gestao.rodoviario.pessoa.Pessoa;


/**
 * Passageiro  um tipo que representa o comportamento de
 * um passageiro no sistema.
 *
 * Exemplo de uso:
 * Passageiro passageiro = new PassageiroAdulto("Maria", "552005-0", "PE", passagem);
 * onde a classe PassageiroAdulto extende a classe Passageiro e implementa os seus
 * mtodos abstratos.
 *
 * @author  ADFT
 */
public abstract class Passageiro extends Pessoa {

    private String telefonePassageiro;
    private Passagem passagemDoPassageiro;

   /**
    * Construtor da classe Passageiro
    *
    * @param nomePassageiro             Nome do passageiro
    * @param identidadePassageiro       Identidade do passageiro
    * @param telefonePassageiro           Estado de origem do passageiro
    * @param passagemPassageiro         Passagem do passageiro
    */
    public Passageiro(String nomePassageiro,
                      String identidadePassageiro,
                      String telefonePassageiro,
                      Passagem passagemPassageiro) {
        super(nomePassageiro,identidadePassageiro);
        this.telefonePassageiro = telefonePassageiro;
        this.passagemDoPassageiro = new Passagem(passagemPassageiro.getData(),
                                                 passagemPassageiro.getViagemDaPassagem(),
                                                 passagemPassageiro.getViagem(),
                                                 passagemPassageiro.getPoltrona(),
                                                 passagemPassageiro.getPreco());
    }

   /**
    * Construtor da classe Onibus que cria um objeto nibus nulo
    */
    public Passageiro() {

        super("","");
        this.telefonePassageiro = "";
        this.passagemDoPassageiro = new Passagem();
    }

    /**
    * Seta o estado de origem do passageiro
    *
    * @param   Uma String contendo o estado de origem do passageiro
    */
    public void settelefonePassageiro(String estado) {
        this.telefonePassageiro = estado;
    }

    /**
    * Retorna o estado de origem do passageiro
    *
    * @return   Uma String o estado de origem do passageiro
    */
    public String gettelefonePassageiro() {
        return this.telefonePassageiro;
    }

    /**
    * Seta a passagem do passageiro
    *
    * @param   Uma String contendo a passagem do passageiro
    */
    public void setPassagemDoPassageiro(Passagem passagem) {
        this.passagemDoPassageiro = passagem;
    }

    /**
    * Retorna a passagem do passageiro
    *
    * @return   Uma String a passagem do passageiro
    */
    public Passagem getPassagemDoPassageiro() {
        return this.passagemDoPassageiro;
    }


    /**
    * Verifica se dois passageiros so iguais comparando seus atributos
    *
    * @return   true se existe igualdade entre todos os atributos
    *           false caso contrrio
    */
    public boolean equals(Passageiro passageiro) {
        boolean resposta = false;
        if (this.getNome().equals(passageiro.getNome())){
            if (this.getIdentidade().equals(passageiro.getIdentidade())) {
                if (this.telefonePassageiro.equals(passageiro.gettelefonePassageiro())) {
                    if (this.getPassagemDoPassageiro().equals(passageiro.getPassagemDoPassageiro())) {
                        resposta = true;
                    }
                }
            }
        }
        return resposta;
    }

    /**
    * Verifica se o passageiro tem seus atributos nulos
    *
    * @return   true se todos os atributos so nulos
    *           false caso contrrio
    */
    public boolean isNull() {
        boolean resposta = false;
        if(this.getNome().equals("")) {
            if(this.getIdentidade().equals("")) {
                if(this.telefonePassageiro.equals("")) {
                    if(this.getPassagemDoPassageiro().isNull()) {
                        resposta = true;
                    }
                }
            }
        }
        return resposta;
    }

    /**
    * Verifica se dois passageiros so semelhantes
    *
    * @return   true se todos os atributos no nulos so iguais
    *           false caso contrrio
    */
    public boolean match(Passageiro passageiro) {
        boolean resposta = true;

        if (passageiro.isNull()) {
            resposta = false;
        }

        if (!passageiro.getNome().equals("")) {
            if((!this.getNome().equals(passageiro.getNome()))) {
                resposta = false;
            }
        }

        if (resposta) {
            if (!passageiro.getIdentidade().equals("")) {
                if (!this.getIdentidade().equals(passageiro.getIdentidade())) {
                    resposta = false;
                }
            }
        }

        if (resposta) {
            if (!passageiro.telefonePassageiro.equals("")) {
                if (!this.telefonePassageiro.equals(passageiro.gettelefonePassageiro())) {
                    resposta = false;
                }
            }
        }

        if (resposta) {
            if (!passageiro.getPassagemDoPassageiro().isNull()) {
                if (!this.getPassagemDoPassageiro().equals(passageiro.getPassagemDoPassageiro())) {
                    resposta = false;
                }
            }
        }

        return resposta;
    }

    public abstract void calculaPrecoPassagem();
}
