/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: PassageiroAdulto
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passageiro;

import gestao.rodoviario.passagem.Passagem;


/**
 * PassageiroAdulto  uma sub-classe da classe Passageiro, que
 * representa um passageiro adulto do sistema.
 *
 * Exemplo de uso:
 * PassageiroAdulto passageiro = new PassageiroAdulto("Sandro","5342531453","PE","passageNova");
 *
 * @author  ADFT
 */
public class PassageiroAdulto extends Passageiro{

   /**
    * Construtor da classe PassageiroAdulto
    *
    * @param nomePassageiro        Nome do passageiro
    * @param identPassageiro       Identidade do passageiro
    * @param estPassageiro         Estado de origem do passageiro
    * @param passPassageiro        Passagem do passageiro
    */
    public PassageiroAdulto(String nomePassageiro,
                           String identPassageiro,
                           String telefone,
                           Passagem passPassageiro){

       // Chamada ao construtor da super classe Passageiro
        super(nomePassageiro,identPassageiro,telefone,passPassageiro);

        // Chamada ao mtodo calculaPrecoPassagem()
        this.calculaPrecoPassagem();
    }

   /**
    * Segundo construtor da classe PassageiroAdulto
    *
    * sem parmetros
    */
    public PassageiroAdulto(){

        // Chamada ao construtor da super classe Passageiro
        // inicializando um passageiro adulto nulo
        super("","","",new Passagem());
    }

   /**
    * Dar um desconto em cima do valor padro da passagem
    */
    public void calculaPrecoPassagem(){
      int valorPadrao = this.getPassagemDoPassageiro().getPreco();
      if(valorPadrao > 0){
          valorPadrao = valorPadrao;
      }
      else{
          valorPadrao = 0;
      }
      this.getPassagemDoPassageiro().setPreco(valorPadrao);
    }
}