/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: PassageiroCrianca
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passageiro;

import gestao.rodoviario.passagem.Passagem;


/**
 * PassageiroCrianca  uma sub-classe da classe Passageiro, que
 * representa um passageiro crianca do sistema.
 *
 * Exemplo de uso:
 * PassageiroCrianca passageiro = new PassageiroCrianca("Sandro","5342531453","PE","passageNova");
 *
 * @author  ADFT
 */
public class PassageiroCrianca extends Passageiro{

   /**
    * Construtor da classe PassageiroCrianca
    *
    * @param nomePassageiro        Nome do passageiro
    * @param identPassageiro       Identidade do passageiro
    * @param estPassageiro         Estado de origem do passageiro
    * @param passPassageiro        Passagem do passageiro
    */
    public PassageiroCrianca(String nomePassageiro,
                           String identPassageiro,
                           String telefone,
                           Passagem passPassageiro) {

        // Chamada ao construtor da super classe Passageiro
        super(nomePassageiro,identPassageiro,telefone,passPassageiro);

        // Chamada ao mtodo calculaPrecoPassagem()
        this.calculaPrecoPassagem();
    }

   /**
    * Segundo construtor da classe PassageiroCrianca
    *
    * sem parmetros
    */
    public PassageiroCrianca(){

        // Chamada ao construtor da super classe Passageiro
        // inicializando um passageiro crianca nulo
        super("","","",new Passagem());
    }

   /**
    * D um desconto em cima do valor padro da passagem
    */
    public void calculaPrecoPassagem(){
        int valorPadrao = this.getPassagemDoPassageiro().getPreco();
        if(valorPadrao > 5){
            valorPadrao = valorPadrao - 5;
        }
        else{
            valorPadrao = 0;
        }
        this.getPassagemDoPassageiro().setPreco(valorPadrao);
    }

}