/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: PassageiroIdoso
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passageiro;

import gestao.rodoviario.passagem.Passagem;


/**
 * PassageiroIdoso  uma sub-classe da classe Passageiro, que
 * representa um passageiro idoso do sistema.
 *
 * Exemplo de uso:
 * PassageiroIdoso passageiro = new PassageiroIdoso("Sandro","5342531453","PE","passageNova");
 *
 * @author  ADFT
 */
public class PassageiroIdoso extends Passageiro {

   /**
    * Construtor da classe PassageiroIdoso
    *
    * @param nomePassageiro        Nome do passageiro
    * @param identPassageiro       Identidade do passageiro
    * @param estPassageiro         Estado de origem do passageiro
    * @param passPassageiro        Passagem do passageiro
    */
    public PassageiroIdoso(String nomePassageiro,
                         String identPassageiro,
                         String telefone,
                         Passagem passPassageiro) {

        // Chamada ao construtor da super classe Passageiro
        super(nomePassageiro,identPassageiro,telefone,passPassageiro);

        // Chamada ao mtodo calculaPrecoPassagem()
        this.calculaPrecoPassagem();
    }

   /**
    * Segundo construtor da classe PassageiroIdoso
    *
    * sem parmetros
    */
    public PassageiroIdoso() {

        // Chamada ao construtor da super classe Passageiro
        // inicializando um passageiro idoso nulo
        super("","","",new Passagem());
    }

   /**
    * Dar um desconto em cima do valor padro da passagem
    */
    public void calculaPrecoPassagem() {
        int valorPadrao = this.getPassagemDoPassageiro().getPreco();
        if(valorPadrao > 10){
            valorPadrao = valorPadrao - 10;
        }
        else{
            valorPadrao = 0;
        }
        this.getPassagemDoPassageiro().setPreco(valorPadrao);
    }
}