/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: CadastroDePassagem
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passagem;

import gestao.rodoviario.excecoes.ObjetoInexistenteException;
import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * CadastroDePassagem  um tipo que possui os mtodos de gerenciamento
 * das passagens do sistema
 *
 * Exemplo de uso:
 * CadastroDePassagem cadastroPassagens = new CadastroDePassagem()
 *
 * @author  ADFT
 */
public class CadastroDePassagem {

    private RepositorioDePassagem listaDePassagem;

   /**
    * Construtor da classe CadastroDePassagem
    */
    public CadastroDePassagem() {
        listaDePassagem = new RepositorioDePassagem();
    }

   /**
    * Encapsulamento do metodo RepositorioDePassagem.inserirPassagem()
    */
    public void inserirPassagemNaListaDePassagem(Passagem passagemParaInserir)
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        listaDePassagem.inserirPassagem(passagemParaInserir);
    }

   /**
    * Encapsulamento do metodo RepositorioDePassagem.removerPassagem()
    */
    public void removerPassagemDaListaDePassagem(Passagem passagemParaRemover)
        throws ObjetoInexistenteException, ObjetoVazioException {
        listaDePassagem.removerPassagem(passagemParaRemover);
    }

   /**
    * Encapsulamento do mtodo
    * RepositorioDePassagem.procurarPassagem().getIterador()
    *
    * @return   Array com o resultado da pesquisa
    */
    public Passagem[] consultarPassagemDaListaDePassagem(Passagem passagemParaConsultar)
        throws ObjetoVazioException, ObjetoJaCadastradoException, ObjetoInexistenteException {
        Passagem[] resultado =  listaDePassagem
                                .procurarPassagem(passagemParaConsultar)
                                .getIterador();
        return resultado;
    }

   /**
    * Retorna todos as passagens cadastrados
    *
    * @return   Array com todos passagens cadastrados
    */
    public Passagem[] getListaDePassagensCadastradas() {
        return (listaDePassagem.getIterador());
    }
}
