/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Passagem
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.passagem;

import gestao.rodoviario.viagem.Viagem;


/**
 * Passagem  um tipo que representa o comportametno de uma passagem no sistema.
 *
 * Exemplo de uso:
 * Passagem passagem = new Passagem()
 *
 * @author  ADFT
 */
public class Passagem {

    private String data;
    private String viagemDaPassagem; // origem/destino
    private Viagem viagem;
    private int poltrona;
    private int preco;

   /**
    * Construtor da classe Passagem
    *
    * @param data                 Data da viagem
    * @param viagemDaPassagem     Origem e destino da viagem
    * @param viagem               Objeto viagem
    * @param poltrona             Poltrona
    * @param preco                Preo
    */
    public Passagem(String data,
                    String viagemDaPassagem,
                    Viagem viagem,
                    int poltrona,
                    int preco) {
        this.data = data;
        this.viagemDaPassagem = viagemDaPassagem;
        this.viagem = viagem;
        this.poltrona = poltrona;
        this.preco = preco;
    }

   /**
    * Construtor da classe Passagem
    */
    public Passagem() {
        this.data = "";
        this.viagemDaPassagem = "";
        this.viagem = new Viagem(); // viagem nula.
        this.poltrona = 0; // as poltronas sero contadas a partir de 1.
        this.preco = 0;
    }

   /**
    * Retorna a data da passagem
    *
    * @return   Uma String contendo a data da passagem
    */
    public String getData() {
        return this.data;
    }

   /**
    * Seta a data da passagem
    *
    * @param   Uma String contendo data da passagem
    */
    public void setData(String data) {
        this.data = data;
    }

   /**
    * Retorna o destino e origem da passagem
    *
    * @return   Uma String contendo o destino e origem
    */
    public String getViagemDaPassagem() {
        return this.viagemDaPassagem;
    }

   /**
    * Seta o destino e origem da passagem
    *
    * @param   Uma String contendo o destino e origem
    */
    public void setViagemDaPassagem(String viagem){
        this.viagemDaPassagem = viagem;
    }

   /**
    * Retorna a viagem da passagem
    *
    * @return   Uma String contendo a viagem da passagem
    */
    public Viagem getViagem() {
        return this.viagem;
    }

   /**
    * Seta a viagem da passagem
    *
    * @param   Uma Viagem
    */
    public void setViagem(Viagem viagem){
        this.viagem = viagem;
    }

   /**
    * Retorna a poltrona da passagem
    *
    * @return   Um inteiro contendo a poltrona
    */
    public int getPoltrona() {
        return this.poltrona;
    }

   /**
    * Seta a poltrona da passagem
    *
    * @param   Um inteiro contendo a poltrona
    */
    public void setPoltrona(int poltrona){
        this.poltrona = poltrona;
    }

   /**
    * Retorna o preo da passagem
    *
    * @return   Uma String contendo data da passagem
    */
    public int getPreco() {
        return this.preco;
    }

   /**
    * Seta o preo da passagem
    *
    * @param   Uma String contendo data da passagem
    */
    public void setPreco(int preco) {
        this.preco = preco;
    }

   /**
    * Verifica se duas passagens so iguais comparando seus atributos
    *
    * @return   true se existe igualdade entre todos os atributos
    *           false caso contrrio
    */
    public boolean equals(Passagem passagem){
        boolean resposta = false;

        if ((this.data.equals(passagem.getData()))){
            if (this.viagemDaPassagem.equals(passagem.getViagemDaPassagem())) {
                if (this.viagem.equals(passagem.getViagem())) {
                    if (this.poltrona == passagem.getPoltrona()) {
                        if (this.preco == passagem.getPreco()) {
                            resposta = true;
                        }
                    }
                }
            }
        }
        return resposta;
    }

   /**
    * Verifica se a passagem tem seus atributos nulos
    *
    * @return   true se todos os atributos so nulos
    *           false caso contrrio
    */
    public boolean isNull(){
        boolean resposta = false;

        if (this.data.equals("")){
            if (this.viagemDaPassagem.equals("")){
                if (this.viagem.isNull()) {
                    if (this.poltrona == 0) {
                        if (this.preco == 0) {
                            resposta = true;
                        }
                    }
                }
            }
        }
        return resposta;
    }

   /**
    * Verifica se duas passagens so semelhantes
    *
    * @return   true se todos os atributos no nulos so iguais
    *           false caso contrrio
    */
    public boolean match(Passagem passagem) {
        boolean resposta = true;

        if (passagem.isNull()) {
            resposta = false;
        }

        if (!passagem.getData().equals("")) {
            if(!this.data.equals(passagem.getData())) {
                resposta = false;
            }
        }

        if (resposta) {
            if(!passagem.getViagemDaPassagem().equals("")) {
                if(!this.viagemDaPassagem.equals(passagem.getViagemDaPassagem())) {
                    resposta = false;
                }
            }
        }

        if (resposta) {
            if(passagem.getPoltrona() != 0) {
                if(this.poltrona != passagem.getPoltrona()){
                    resposta = false;
                }
            }
        }

       if (resposta) {
            if(passagem.getPreco() != 0) {
                if(this.preco != passagem.getPreco()) {
                    resposta = false;
                }
            }
       }

       if (resposta) {
            if(!passagem.getViagem().isNull()) {
                if(!this.viagem.equals(passagem.getViagem()) ) {
                    resposta = false;
                }
            }
       }
       return resposta;
    }

}
