/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: CadastroDeViagem
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.viagem;

import gestao.rodoviario.excecoes.ObjetoInexistenteException;
import gestao.rodoviario.excecoes.ObjetoJaCadastradoException;
import gestao.rodoviario.excecoes.ObjetoVazioException;


/**
 * CadastroDeViagem  um tipo que possui os mtodos de gerenciamento
 * das viagens do sistema
 *
 * Exemplo de uso:
 * CadastroDeViagem cadastroViagens = new CadastroDeViagem()
 *
 * @author  ADFT
 */
public class CadastroDeViagem {

    private RepositorioDeViagem listaDeViagem;

   /**
    * Construtor da classe CadastroDeViagem
    */
    public CadastroDeViagem() {
        listaDeViagem = new RepositorioDeViagem();
    }

   /**
    * Encapsulamento do metodo RepositorioDeViagem.removerViagem()
    */
    public void inserirViagemNaListaDeViagem(Viagem viagemParaInserir)
        throws ObjetoJaCadastradoException, ObjetoVazioException {
        listaDeViagem.inserirViagem(viagemParaInserir);
    }

   /**
    * Encapsulamento do metodo RepositorioDeViagem.removerViagem()
    */
    public void removerViagemDaListaDeViagem(Viagem viagemParaRemover)
        throws ObjetoInexistenteException, ObjetoVazioException {
        listaDeViagem.removerViagem(viagemParaRemover);
    }

   /**
    * Encapsulamento do mtodo
    * RepositorioDeViagem.procurarViagem().getIterador()
    *
    * @return   Array com o resultado da pesquisa
    */
    public Viagem[] consultarViagemDaListaDeViagem(Viagem viagemParaConsultar)
        throws ObjetoVazioException, ObjetoJaCadastradoException {
        Viagem[] resultado = listaDeViagem
                             .procurarViagem(viagemParaConsultar)
                             .getIterador();
        return resultado;
    }

   /**
    * Retorna todos as viagens cadastradas
    *
    * @return   Array com todos viagens cadastrados
    */
    public Viagem[] getListaDeViagensCadastradas() {
        return (listaDeViagem.getIterador());
    }
}
