/*
 * Projeto: SGER - Sistema Gestor de Empresas Rodovirias
 *
 * Tipo: Viagem
 *
 * Marca Registrada (c) 2002 ADFT
 * Grupo do Centro de Informtica da UFPE, Recife-PE
 * Todos os direitos reservados.
 */

package gestao.rodoviario.viagem;

import gestao.rodoviario.onibus.Onibus;


/**
 * Viagem  um tipo que representa o comportamento de uma viagem no sistema.
 *
 * Exemplo de uso:
 * Viagem viagem = new Viagem()
 *
 * @author  ADFT
 */
public class Viagem {

    private String embarque;
    private String desembarque;
    private Onibus onibusDaViagem;
    private int horaPartida;
    private int horaChegada;
    private int distancia;
    private int tempoDeViagem;
    private int custoDaViagem;

   /**
    * Construtor da classe Viagem
    *
    * @param embarque       Local do embarque
    * @param desembarque    Local do desembarque
    * @param onibus         Onibus da viagem
    * @param horaPartida    Hora da partida
    * @param horaChegada    Hora da chegada
    * @param distancia      Distncia da viagem
    * @param tempo          Tempo de durao da viagem
    * @param custo          Custo da viagem
    */
    public Viagem (String embarque,
                  String desembarque,
                  Onibus onibus,
                  int horaPartida,
                  int horaChegada,
                  int distancia,
                  int tempo,
                  int custo) {

        this.embarque = embarque;
        this.desembarque = desembarque;
        this.onibusDaViagem = onibus;
        this.horaPartida = horaPartida;
        this.horaChegada = horaChegada;
        this.distancia = distancia;
        this.tempoDeViagem = tempo;
        this.custoDaViagem = custo;
    }

   /**
    * Construtor da classe Viagem
    */
    public Viagem() {
        this.embarque = "";
        this.desembarque = "";
        this.onibusDaViagem = new Onibus();
        this.horaPartida = 100; // a hora de fincionamento ser das 4 s 22 horas
        this.horaChegada = 100; // a hora de fincionamento ser das 4 s 22 horas
        this.distancia = 0;
        this.tempoDeViagem = 0;
        this.custoDaViagem = 0;
    }

   /**
    * Retorna o local do embarque
    *
    * @return   Uma String contendo o local do embarque
    */
    public String getEmbarque() {
        return this.embarque;
    }

   /**
    * Seta o local do embarque
    *
    * @param   Uma String contendo o local do embarque
    */
    public void setEmbarque(String embarque) {
        this.embarque = embarque;
    }

   /**
    * Retorna o local do desembarque
    *
    * @return   Uma String contendo o local do desembarque
    */
    public String getDesembarque() {
        return this.desembarque;
    }

    /**
    * Seta o local do desembarque
    *
    * @param   Uma String contendo o local do desembarque
    */
    public void setDesembarque(String desembarque) {
        this.desembarque = desembarque;
    }

   /**
    * Retorna o onibus da viagem
    *
    * @return   Um Onibus
    */
    public Onibus getOnibusDaViagem() {
        return this.onibusDaViagem;
    }

    /**
    * Seta o o onibus da viagem
    *
    * @param   Um Onibus
    */
    public void getOnibusDaViagem(Onibus onibus) {
        this.onibusDaViagem = onibus;
    }

   /**
    * Retorna a hora da partida
    *
    * @return   Um inteiro contendo a hora da partida
    */
    public int getHoraPartida() {
        return this.horaPartida;
    }

    /**
    * Seta a hora da partida
    *
    * @param   Um inteiro contendo a hora da partida
    */
    public void setHoraPartida(int horaPartida) {
        this.horaPartida = horaPartida;
    }

   /**
    * Retorna a hora da chegada
    *
    * @return   Um inteiro contendo a hora da chegada
    */
    public int getHoraChegada() {
        return this.horaChegada;
    }

    /**
    * Seta a hora da chegada
    *
    * @param   Um inteiro contendo a hora da chegada
    */
    public void setHoraChegada(int horaChegada) {
         this.horaChegada = horaChegada;
    }

   /**
    * Retorna a distncia da viagem
    *
    * @return   Um inteiro contendo a distncia da viagem
    */
    public int getDistancia() {
        return this.distancia;
    }

    /**
    * Seta a distncia da viagem
    *
    * @param   Um inteiro contendo a distncia da viagem
    */
    public void setDistancia(int distancia) {
         this.distancia = distancia;
    }

   /**
    * Retorna o tempo da viagem
    *
    * @return   Um int contendo o tempo da viagem
    */
    public int getTempoDeViagem() {
        return this.tempoDeViagem;
    }

    /**
    * Seta o tempo da viagem
    *
    * @param   Um int contendo o tempo da viagem
    */
    public void setTempoDeViagem(int tempoDeViagem) {
         this.tempoDeViagem = tempoDeViagem;
    }

   /**
    * Retorna o custo da viagem
    *
    * @return   Um inteiro contendo o custo da viagem
    */
    public int getCustoDaViagem() {
        return this.custoDaViagem;
    }

    /**
    * Seta o custo da viagem
    *
    * @param   Um inteiro contendo o custo da viagem
    */
    public void setCustoDaViagem(int custoDaViagem) {
         this.custoDaViagem = custoDaViagem;
    }

   /**
    * Verifica se duas viagens so iguais comparando seus atributos
    *
    * @return   true se existe igualdade entre todos os atributos
    *           false caso contrrio
    */
    public boolean equals(Viagem viagem) {
        boolean resposta = false;

        if((this.embarque.equals(viagem.getEmbarque())))
            if(this.desembarque.equals(viagem.getDesembarque()))
                if(this.onibusDaViagem.equals(viagem.getOnibusDaViagem()))
                    if(this.horaPartida == viagem.getHoraPartida())
                        if(this.horaChegada == viagem.getHoraChegada())
                            if(this.distancia == viagem.getDistancia())
                                if(this.tempoDeViagem == viagem.getTempoDeViagem())
                                    if(this.custoDaViagem == viagem.getCustoDaViagem())
                                        resposta = true;

        return resposta;
    }

   /**
    * Verifica se a viagem tem seus atributos nulos
    *
    * @return   true se todos os atributos so nulos
    *           false caso contrrio
    */
    public boolean isNull() {
        boolean resposta = false;

        if (this.embarque.equals(""))
            if (this.desembarque.equals(""))
                if (this.onibusDaViagem.isNull())
                    if (this.horaPartida == 100)
                        if (this.horaChegada == 100)
                            if (this.distancia == 0)
                                if (this.tempoDeViagem == 0)
                                    if (this.custoDaViagem == 0)
                                        resposta = true;

        return resposta;
    }

   /**
    * Verifica se duas viagens so semelhantes
    *
    * @return   true se todos os atributos no nulos so iguais
    *           false caso contrrio
    */
    public boolean match(Viagem viagem) {
        boolean resultado = true;

        if (viagem.isNull()) {
            resultado = false;
        }

        if (!viagem.getEmbarque().equals("")) {
            if (!this.embarque.equals(viagem.getEmbarque()))  {
                resultado = false;
            }
        }

        if (resultado) {
            if (!viagem.getDesembarque().equals("")) {
                if (!this.desembarque.equals(viagem.getDesembarque())) {
                    resultado = false;
                }
            }
        }

        if (resultado) {
            if (!viagem.getOnibusDaViagem().isNull()) {
                if (!this.onibusDaViagem.equals(viagem.getOnibusDaViagem())) {
                    resultado = false;
                }
            }
        }

        if (resultado) {
            if (viagem.getHoraPartida() != 100) {
                if (this.horaPartida != viagem.getHoraPartida()) {
                    resultado = false;
                }
            }
        }

        if (resultado) {
            if (viagem.getHoraChegada() != 100) {
                if (this.horaChegada != viagem.getHoraChegada()) {
                    resultado = false;
                }
            }
        }

        if (resultado) {
            if (viagem.getDistancia() != 0) {
                if (this.distancia != viagem.getDistancia()) {
                    resultado = false;
                }
            }
        }

        if (resultado){
            if (viagem.getTempoDeViagem() != 0) {
                if (this.tempoDeViagem != viagem.getTempoDeViagem()) {
                    resultado = false;
                }
            }
        }

        if (resultado) {
            if (viagem.getCustoDaViagem() != 0) {
                if (this.custoDaViagem != viagem.getCustoDaViagem()) {
                    resultado = false;
                }
            }
        }

        return resultado;
    }
}
